unit uMain;

interface

uses
	Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
	Dialogs, StdCtrls, ExtCtrls, ComCtrls;

type


	TfrmArgowMobile_ui = class(TForm)
		od: TOpenDialog;
    pnlBottom: TPanel;
    pnlBack: TPanel;
    pnlAbout: TPanel;
    pnlControl: TPanel;
    pnlInfo: TPanel;
    gbxInfo: TGroupBox;
    lblBattery: TLabel;
    lblMemoria: TLabel;
    pgbBattery: TProgressBar;
    pgbMemory: TProgressBar;
    edtInfo: TEdit;
    pnlTransfer: TPanel;
    gbxTransfer: TGroupBox;
    lblFolder_PC: TLabel;
    lblFolder_Mobile: TLabel;
    edtFolder_PC: TEdit;
    btnPcFile: TButton;
    edtFolder_Mobile: TEdit;
    btnGet: TButton;
    btnPut: TButton;
    pnlSep1: TPanel;
    lblArgow: TLabel;
    lblFileName: TLabel;
    edtFileName: TEdit;
    btnInfo: TButton;
    gbxAbout: TGroupBox;
    mmoAbout: TMemo;
		procedure FormCreate(Sender: TObject);
		procedure btnInfoClick(Sender: TObject);
		procedure btnPcFileClick(Sender: TObject);
		procedure btnGetClick(Sender: TObject);
		procedure btnPutClick(Sender: TObject);
    procedure lblArgowClick(Sender: TObject);
	private
		procedure enableButtons(const Value: boolean);
		procedure refreshInfo;
	end;

var
	frmArgowMobile_ui: TfrmArgowMobile_ui;

implementation
	uses
    math,
    ShellAPI,
    strUtils,
    UxTheme,
    Dwmapi,
		CommCtrl,
    arMobile_const,
		arMobile_interface;

  const
  	eol= #13#10;

{$R *.dfm}
//==============================================================================
function user_msg( const cMsg, cTitle: string; const iFlags: integer= MB_OK + MB_ICONINFORMATION ): integer;
begin
  result:= application.MessageBox( pChar( StringReplace( cMsg, '|', eol, [ rfReplaceAll ] ) ), pChar( cTitle ), iFlags );

end;

//==============================================================================
procedure TfrmArgowMobile_ui.FormCreate(Sender: TObject);
	var cText: string;
begin
	inherited;

	showHint:= true;
  if Dwmapi.DwmCompositionEnabled then begin
    self.GlassFrame.Bottom:= pnlBottom.Height;
    self.GlassFrame.Enabled:= true;
    lblArgow.GlowSize:= 1;
  end;

  cText:= stringReplace( mmoAbout.Text, eol, '', [ rfReplaceAll ]);;
	mmoAbout.Text:= stringReplace( cText, '|', eol, [ rfReplaceAll ]);
	mmoAbout.WordWrap:= true;
	lblArgow.Left:= pnlBottom.ClientWidth - lblArgow.Width - 5;
   // see http://msdn.microsoft.com/en-us/library/bb773175(VS.85).aspx#turnoff
  setWindowTheme( pgbBattery.Handle, ' ', ' ');
  setWindowTheme( pgbMemory.Handle, ' ', ' ');

end;

//==============================================================================
procedure TfrmArgowMobile_ui.enableButtons( const value: boolean );
begin
  screen.Cursor:= ifThen( value, crDefault, crHourGlass );
  btnInfo.Enabled:= value;
  btnPcFile.Enabled:= value;
  btnGet.Enabled:= value;
  btnPut.Enabled:= value;

end;

//==============================================================================
procedure TfrmArgowMobile_ui.refreshInfo;
	//----------------------------------------------------------------------------
	procedure _setPos( pgb: TProgressBar; const iPos, iOK: integer );
    var iColor: TColor;
	begin
		pgb.Position:= iPos;
		pgb.Hint:= format( '%d%%', [ iPos ] );
    pgb.tag:= 1;
    case iOk of
      00..20: iColor:= clRed;
      21..40: iColor:= clWebOrangeRed;
      41..60: iColor:= clWebOrange;
      61..80: iColor:= clWebYellowGreen;
    else
      iColor:= clWebForestGreen;
    end;
		sendMessage( pgb.Handle, PBM_SETBARCOLOR, 0, longint( colortoRgb( iColor )));
		// http://msdn.microsoft.com/en-us/library/aa511486.aspx#metersguidelines
		// use meters, no progressbar
	end;
	//----------------------------------------------------------------------------
	procedure _setInfo( const cText: string; bConnected: boolean= false );
	begin
		edtInfo.Text:= cText;
		if not bConnected then begin
      _setPos( pgbBattery, 0, 0 );
      _setPos( pgbMemory, 0, 0 );
    end;
	end;
	//----------------------------------------------------------------------------
	var info: TArMobileInfo;
begin

  enableButtons( false );
	try
		lblBattery.Caption:= 'Bateria';
		mobile_getInfo( 100, info );
		case info.code of
			ArMobile_DllError:    _setInfo( 'DLL no encontrada: ' + arMobile_const.ArMobile_Dll);
			ArMobile_NotFound:    _setInfo( 'Dispositivo no encontrado' );
			ArMobile_CantConnect: _setInfo( 'No consegui informaes do dispositivo' );
			ArMobile_Ok: begin
				_setInfo( format( 'Windows CE OS %d.%d', [ info.osVerMajor, info.osVerMinor ] ), true);
				_setPos( pgbBattery, info.batteryLeft, info.batteryLeft );
				_setPos( pgbMemory, info.usedMemory, 100- info.usedMemory);
				lblBattery.Caption:= lblBattery.Caption + ifThen( info.charging, ' (Cargando)', '' );
			end;
		end;
	finally
    enableButtons( true );
	end;

end;
//==============================================================================
// botoes
//==============================================================================
procedure TfrmArgowMobile_ui.btnInfoClick(Sender: TObject);
begin
	inherited;
	refreshInfo();

end;

//==============================================================================
procedure TfrmArgowMobile_ui.btnPcFileClick(Sender: TObject);
begin
	inherited;
	if od.Execute then begin
    edtFileName.Text:= ExtractFileName( od.FileName );
    edtFolder_PC.Text:= ExtractFilePath( od.FileName );
  end;

end;

//==============================================================================
procedure TfrmArgowMobile_ui.btnGetClick(Sender: TObject);
	//----------------------------------------------------------------------------
	function _overwrite( const cFileName: string ): boolean;
	begin
		if not fileExists( cFileName ) then begin
			result:= true;
		end else if not ( user_msg( 'O destino ' + cFileName + '|j existe. Deseja sobrescrever o arquivo?', btnGet.Caption,  MB_YESNO + MB_ICONQUESTION ) = IDYES ) then begin
			result:= false;
		end else if deleteFile( cFileName ) then begin
			result:= true;
		end else begin
			user_msg( 'No foi possvel remover o arquivo destino:|' + cFileName, btnGet.Caption );
			result:= false;
		end;
	end;
	//----------------------------------------------------------------------------
	var
		cDestiny, cSource: string;
		iCode: integer;
begin
	inherited;

	cDestiny:= IncludeTrailingPathDelimiter( edtFolder_Pc.Text ) + edtFileName.Text;
	cSource:= IncludeTrailingPathDelimiter( edtFolder_Mobile.Text ) + edtFileName.Text;
	if _overwrite( cDestiny ) then begin
		enableButtons(false);
		try
			iCode:= mobile_copyMobileToPC( pChar(cSource), pChar(cDestiny) );
			if ( iCode = ERROR_SUCCESS ) then begin
				user_msg( 'Arquivo transferido.', btnGet.Caption );
			end else begin
				user_msg( 'Erro ao transferir o arquivo do dispositivo:|' + cSource + '||' + SysErrorMessage(iCode), btnGet.Caption, MB_OK + MB_ICONWARNING );
			end;
		finally
			enableButtons(true);
		end;
	end;

end;

//==============================================================================
procedure TfrmArgowMobile_ui.btnPutClick(Sender: TObject);
	var
		cDestiny, cSource: string;
		iCode: integer;
begin
	inherited;

	cDestiny:= IncludeTrailingPathDelimiter( edtFolder_Mobile.Text ) + edtFileName.Text;
	cSource:=  IncludeTrailingPathDelimiter( edtFolder_PC.Text ) + edtFileName.Text;
	if not fileExists( cSource ) then begin
		user_msg( 'No encontrei o arquivo origem:|' + cSource, btnPut.Caption );
	end else begin
		enableButtons(false);
		try
			iCode:= mobile_copyPCToMobile( pChar(cSource), pChar(cDestiny) );
			if ( iCode = ERROR_SUCCESS ) then begin
				user_msg( 'Arquivo transferido.', btnPut.Caption );
			end else begin
				user_msg( 'Erro transferir o arquivo local|' + cSource + '|para o dispositivo.||' + SysErrorMessage( iCode ), btnPut.Caption, MB_OK + MB_ICONWARNING );
			end;
		finally
			enableButtons(true);
		end;
	end;

end;

//==============================================================================
procedure TfrmArgowMobile_ui.lblArgowClick(Sender: TObject);
begin
  ShellExecute( 0, 'open', pChar(lblArgow.Caption), '', '', 0 );

end;


end.

